@@ -1,14 +1,21 @@
 """
      nester.py prvodies one function called print_lol() which prints lists that may
-     may or may not include nested lists.
+     may or may not include nested lists. The nested list are indented num_tab
+     times
 """
-def print_lol(the_list):
+movies = [ "one", "two",
+          [ "three",
+                 [ "four", "five", "six" ]]]
+
+def print_lol(the_list, num_tab):
      """
         Takes a positional argument called "the list" which is any python list
         and print each item on its own line.
      """
      for each_item in the_list:
           if isinstance(each_item, list):
-               print_lol(each_item)
+               print_lol(each_item, num_tab+1)
           else:
+               for each_tab in range(num_tab):
+                    print("\t", end='')
                print(each_item)
